@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Directory Replication
 #  listener module for Directory replication
@@ -41,7 +40,7 @@
 # 2. Primary is degraded to Replica
 #    use existing database
 
-from __future__ import absolute_import, annotations, print_function
+from __future__ import annotations
 
 import base64
 import os
@@ -50,14 +49,14 @@ import smtplib
 import subprocess
 import sys
 import time
+from email.mime.text import MIMEText
 from errno import ENOENT
-from typing import Any, Dict, List, Tuple
+from typing import Any
 
 import ldap
 import ldap.schema
 # import ldif as ldifparser since the local module already uses ldif as variable
 import ldif as ldifparser
-from six.moves.email_mime_text import MIMEText
 
 import univention.debug as ud
 
@@ -83,7 +82,7 @@ ROOTPW_FILE = '/etc/ldap/rootpw.conf'
 CURRENT_MODRDN = os.path.join(STATE_DIR, 'current_modrdn')
 MAX_LDAP_RETRIES = int(listener.configRegistry.get('replication/ldap/retries', '30'))
 
-EXCLUDE_ATTRIBUTES = {attr.lower() for attr in {
+EXCLUDE_ATTRIBUTES = {attr.lower() for attr in (
     'subschemaSubentry',
     'hasSubordinates',
     'entryDN',
@@ -95,14 +94,14 @@ EXCLUDE_ATTRIBUTES = {attr.lower() for attr in {
     'pwdGraceUseTime',
     'pwdReset',
     'pwdPolicySubentry',
-} | (set() if listener.configRegistry.is_true('ldap/overlay/memberof') else {'memberOf'})}
+)}
 ud.debug(ud.LISTENER, ud.ALL, 'replication: EXCLUDE_ATTRIBUTES=%r' % (EXCLUDE_ATTRIBUTES,))
 
 # exclude built-in OIDs from slapd
 BUILTIN_OIDS = {line.strip() for line in open("/usr/share/univention-ldap/oid_skip")}
 
 
-class LDIFObject(object):
+class LDIFObject:
 
     def __init__(self, filename: str) -> None:
         self.fp = open(filename, 'ab')
@@ -113,7 +112,7 @@ class LDIFObject(object):
         encode = b'\n' in value
         try:
             if isinstance(value, tuple):
-                (newval, leng) = value
+                (newval, _leng) = value
             else:
                 newval = value
             newval.decode('ascii')
@@ -150,7 +149,7 @@ class LDIFObject(object):
     def __end_section(self) -> None:
         self.fp.write(b'-\n')
 
-    def add_s(self, dn: str, al: List[Tuple[str, Any]]) -> None:
+    def add_s(self, dn: str, al: list[tuple[str, Any]]) -> None:
         self.__new_entry(dn)
         self.__print_attribute('changetype', b'add')
         for attr, vals in al:
@@ -158,7 +157,7 @@ class LDIFObject(object):
                 self.__print_attribute(attr, val)
         self.__end_entry()
 
-    def modify_s(self, dn: str, ml: List[Tuple[int, str, Any]]) -> None:
+    def modify_s(self, dn: str, ml: list[tuple[int, str, Any]]) -> None:
         self.__new_entry(dn)
         self.__print_attribute('changetype', b'modify')
         for ldap_op, attr, vals in ml:
@@ -222,12 +221,12 @@ def connect(ldif: bool = False) -> ldap.ldapobject:
     return connection
 
 
-def addlist(new: Dict[str, List[bytes]]) -> List[Tuple[str, List[bytes]]]:
+def addlist(new: dict[str, list[bytes]]) -> list[tuple[str, list[bytes]]]:
     return [kv for kv in new.items() if kv[0].lower() not in EXCLUDE_ATTRIBUTES]
 
 
-def modlist(old: Dict[str, List[bytes]], new: Dict[str, List[bytes]]) -> List[Tuple[int, str, List[bytes]]]:
-    ml: List[Tuple[int, str, List[bytes]]] = []
+def modlist(old: dict[str, list[bytes]], new: dict[str, list[bytes]]) -> list[tuple[int, str, list[bytes]]]:
+    ml: list[tuple[int, str, list[bytes]]] = []
     for key, values in new.items():
         if key.lower() in EXCLUDE_ATTRIBUTES:
             continue
@@ -241,7 +240,7 @@ def modlist(old: Dict[str, List[bytes]], new: Dict[str, List[bytes]]) -> List[Tu
         if set_old == set_new:
             continue
 
-        if key == listener.configRegistry.get('ldap/overlay/memberof/member', 'uniqueMember'):
+        if key == 'uniqueMember':
             # triggers slapd-memberof, where REPLACE is inefficient (Bug #48545)
             added_items = set_new - set_old
             removed_items = set_old - set_new
@@ -262,7 +261,7 @@ def modlist(old: Dict[str, List[bytes]], new: Dict[str, List[bytes]]) -> List[Tu
     return ml
 
 
-def subschema_oids_with_sup(subschema: ldap.schema.subentry.SubSchema, ldap_type: ldap.schema.SchemaElement, oid: str, result: List[str]) -> None:
+def subschema_oids_with_sup(subschema: ldap.schema.subentry.SubSchema, ldap_type: ldap.schema.SchemaElement, oid: str, result: list[str]) -> None:
     if oid in BUILTIN_OIDS or oid in result:
         return
 
@@ -273,14 +272,14 @@ def subschema_oids_with_sup(subschema: ldap.schema.subentry.SubSchema, ldap_type
     result.append(oid)
 
 
-def subschema_sort(subschema: ldap.schema.subentry.SubSchema, ldap_type: ldap.schema.SchemaElement) -> List[str]:
-    result: List[str] = []
+def subschema_sort(subschema: ldap.schema.subentry.SubSchema, ldap_type: ldap.schema.SchemaElement) -> list[str]:
+    result: list[str] = []
     for oid in subschema.listall(ldap_type):
         subschema_oids_with_sup(subschema, ldap_type, oid, result)
     return result
 
 
-def update_schema(attr: Dict[str, List[bytes]]) -> None:
+def update_schema(attr: dict[str, list[bytes]]) -> None:
     def _insert_linebreak(obj: str) -> str:
         # Bug 46743: Ensure lines are not longer than 2000 characters or slapd fails to start
         max_length = 2000
@@ -326,7 +325,7 @@ def update_schema(attr: Dict[str, List[bytes]]) -> None:
     init_slapd('restart')
 
 
-def getOldValues(ldapconn: ldap.ldapobject, dn: str) -> Dict[str, List[bytes]]:
+def getOldValues(ldapconn: ldap.ldapobject, dn: str) -> dict[str, list[bytes]]:
     """
     get "old" from local ldap server
     "ldapconn": connection to local ldap server
@@ -382,12 +381,12 @@ def _remove_file(pathname: str) -> None:
     ud.debug(ud.LISTENER, ud.ALL, 'replication: removing %s' % (pathname,))
     try:
         os.remove(pathname)
-    except EnvironmentError as ex:
+    except OSError as ex:
         if ex.errno != ENOENT:
             ud.debug(ud.LISTENER, ud.ERROR, 'replication: failed to remove %s: %s' % (pathname, ex))
 
 
-def _add_object_from_new(lo: ldap.ldapobject, dn: str, new: Dict[str, List[bytes]]) -> None:
+def _add_object_from_new(lo: ldap.ldapobject, dn: str, new: dict[str, list[bytes]]) -> None:
     al = addlist(new)
     try:
         lo.add_s(dn, al)
@@ -395,7 +394,7 @@ def _add_object_from_new(lo: ldap.ldapobject, dn: str, new: Dict[str, List[bytes
         log_ldap(ud.ERROR, 'object class violation while adding', ex, dn=dn)
 
 
-def _modify_object_from_old_and_new(lo: ldap.ldapobject, dn: str, old: Dict[str, List[bytes]], new: Dict[str, List[bytes]]) -> None:
+def _modify_object_from_old_and_new(lo: ldap.ldapobject, dn: str, old: dict[str, list[bytes]], new: dict[str, list[bytes]]) -> None:
     ml = modlist(old, new)
     if ml:
         ud.debug(ud.LISTENER, ud.ALL, 'replication: modify: %s' % dn)
@@ -408,7 +407,7 @@ def _read_dn_from_file(filename: str) -> str | None:
     try:
         with open(filename) as fd:
             old_dn = fd.read()
-    except EnvironmentError as ex:
+    except OSError as ex:
         ud.debug(ud.LISTENER, ud.ERROR, 'replication: failed to open/read modrdn file %s: %s' % (filename, ex))
 
     return old_dn
@@ -447,7 +446,7 @@ def check_file_system_space() -> None:
     listener.run('/usr/bin/systemctl', ['systemctl', 'stop', 'univention-directory-listener'], uid=0, wait=True)
 
 
-def handler(dn: str, new: Dict[str, List[bytes]], listener_old: Dict[str, List[bytes]], operation: str) -> Any:
+def handler(dn: str, new: dict[str, list[bytes]], listener_old: dict[str, list[bytes]], operation: str) -> Any:
     global reconnect
     if not slave:
         return 1
@@ -590,7 +589,7 @@ def handler(dn: str, new: Dict[str, List[bytes]], listener_old: Dict[str, List[b
                     os.symlink(modrdn_cache, CURRENT_MODRDN)
                     # that's it for now for command 'r' ==> modrdn will follow in the next step
                     return
-                except EnvironmentError as ex:
+                except OSError as ex:
                     # d'oh! output some message and continue doing a delete+add instead
                     ud.debug(ud.LISTENER, ud.ERROR, 'replication: failed to open/write modrdn file %s: %s' % (modrdn_cache, ex))
 
